@@ -1,6 +1,6 @@
 package Spreadsheet::ParseXLSX;
 our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::VERSION = '0.20';
+$Spreadsheet::ParseXLSX::VERSION = '0.23';
 use strict;
 use warnings;
 use 5.008;
@@ -35,10 +35,11 @@ sub parse {
     my $workbook = Spreadsheet::ParseExcel::Workbook->new;
 
     if ($self->_check_signature($file)) {
-        $file = Spreadsheet::ParseXLSX::Decryptor->open(
+        my $decrypted_file = Spreadsheet::ParseXLSX::Decryptor->open(
             $file,
             $self->{Password}
         );
+        $file = $decrypted_file if $decrypted_file;
     }
 
     if (openhandle($file)) {
@@ -88,8 +89,8 @@ sub _parse_workbook {
 
     my $files = $self->_extract_files($zip);
 
-    my ($version)    = $files->{workbook}->find_nodes('//fileVersion');
-    my ($properties) = $files->{workbook}->find_nodes('//workbookPr');
+    my ($version)    = $files->{workbook}->find_nodes('//s:fileVersion');
+    my ($properties) = $files->{workbook}->find_nodes('//s:workbookPr');
 
     if ($version) {
         $workbook->{Version} = $version->att('appName')
@@ -113,8 +114,14 @@ sub _parse_workbook {
     $workbook->{FormatStr} = $styles->{FormatStr};
     $workbook->{Font}      = $styles->{Font};
 
-    $workbook->{PkgStr} = $self->_parse_shared_strings($files->{strings})
-        if $files->{strings};
+    if ($files->{strings}) {
+        my %string_parse_data = $self->_parse_shared_strings(
+            $files->{strings},
+            $themes->{Color}
+        );
+        $workbook->{PkgStr} = $string_parse_data{PkgStr};
+        $workbook->{Rich}   = $string_parse_data{Rich};
+    }
 
     # $workbook->{StandardWidth} = ...;
 
@@ -124,7 +131,7 @@ sub _parse_workbook {
     # $workbook->{PrintTitle} = ...;
 
     my @sheets = map {
-        my $idx = $_->att('r:id');
+        my $idx = $_->att('rels:id');
         if ($files->{sheets}{$idx}) {
           my $sheet = Spreadsheet::ParseExcel::Worksheet->new(
               Name     => $_->att('name'),
@@ -137,12 +144,12 @@ sub _parse_workbook {
         } else {
           ()
         }
-    } $files->{workbook}->find_nodes('//sheets/sheet');
+    } $files->{workbook}->find_nodes('//s:sheets/s:sheet');
 
     $workbook->{Worksheet}  = \@sheets;
     $workbook->{SheetCount} = scalar(@sheets);
 
-    my ($node) = $files->{workbook}->find_nodes('//workbookView');
+    my ($node) = $files->{workbook}->find_nodes('//s:workbookView');
     my $selected = $node ? $node->att('activeTab') : undef;
     $workbook->{SelectedSheet} = defined($selected) ? 0+$selected : 0;
 
@@ -159,7 +166,7 @@ sub _parse_sheet {
     $sheet->{MaxCol} = -1;
     $sheet->{Selection} = [ 0, 0 ];
 
-    my @merged_cells;
+    my %merged_cells;
 
     my @column_formats;
     my @column_widths;
@@ -170,10 +177,12 @@ sub _parse_sheet {
     my $default_row_height   = 15;
     my $default_column_width = 10;
 
-    my $sheet_xml = XML::Twig->new(
+    my %cells;
+
+    my $sheet_xml = $self->_new_twig(
         twig_roots => {
             #XXX need a fallback here, the dimension tag is optional
-            'dimension' => sub {
+            's:dimension' => sub {
                 my ($twig, $dimension) = @_;
 
                 my ($rmin, $cmin, $rmax, $cmax) = $self->_dimensions(
@@ -188,11 +197,11 @@ sub _parse_sheet {
                 $twig->purge;
             },
 
-            'headerFooter' => sub {
+            's:headerFooter' => sub {
                 my ($twig, $hf) = @_;
 
                 my ($helem, $felem) = map {
-                    $hf->first_child($_)
+                    $hf->first_child("s:$_")
                 } qw(oddHeader oddFooter);
                 $sheet->{Header} = $helem->text
                     if $helem;
@@ -202,7 +211,7 @@ sub _parse_sheet {
                 $twig->purge;
             },
 
-            'pageMargins' => sub {
+            's:pageMargins' => sub {
                 my ($twig, $margin) = @_;
                 map {
                     my $key = "\u${_}Margin";
@@ -213,7 +222,7 @@ sub _parse_sheet {
                 $twig->purge;
             },
 
-            'pageSetup' => sub {
+            's:pageSetup' => sub {
                 my ($twig, $setup) = @_;
                 $sheet->{Scale} = defined $setup->att('scale')
                                 ? $setup->att('scale')
@@ -230,7 +239,7 @@ sub _parse_sheet {
                 $twig->purge;
             },
 
-            'mergeCells/mergeCell' => sub {
+            's:mergeCells/s:mergeCell' => sub {
                 my ( $twig, $merge_area ) = @_;
 
                 if (my $ref = $merge_area->att('ref')) {
@@ -245,7 +254,7 @@ sub _parse_sheet {
                     ];
                     for my $row ($toprow .. $bottomrow) {
                         for my $col ($leftcol .. $rightcol) {
-                            push(@merged_cells, [$row, $col]);
+                            $merged_cells{"$row;$col"} = 1;
                         }
                     }
                 }
@@ -253,7 +262,7 @@ sub _parse_sheet {
                 $twig->purge;
             },
 
-            'sheetFormatPr' => sub {
+            's:sheetFormatPr' => sub {
                 my ( $twig, $format ) = @_;
 
                 $default_row_height   = $format->att('defaultRowHeight')
@@ -264,28 +273,28 @@ sub _parse_sheet {
                 $twig->purge;
             },
 
-            'col' => sub {
+            's:col' => sub {
                 my ( $twig, $col ) = @_;
 
                 for my $colnum ($col->att('min')..$col->att('max')) {
                     $column_widths[$colnum - 1] = $col->att('width');
                     $column_formats[$colnum - 1] = $col->att('style');
-                    $columns_hidden[$colnum - 1] = $col->att('hidden');
+                    $columns_hidden[$colnum - 1] = $self->_xml_boolean($col->att('hidden'));
                 }
 
                 $twig->purge;
             },
 
-            'row' => sub {
+            's:row' => sub {
                 my ( $twig, $row ) = @_;
 
                 $row_heights[ $row->att('r') - 1 ] = $row->att('ht');
-                $rows_hidden[ $row->att('r') - 1 ] = $row->att('hidden');
+                $rows_hidden[ $row->att('r') - 1 ] = $self->_xml_boolean($row->att('hidden'));
 
                 $twig->purge;
             },
 
-            'selection' => sub {
+            's:selection' => sub {
                 my ( $twig, $selection ) = @_;
 
                 if (my $cell = $selection->att('activeCell')) {
@@ -302,7 +311,7 @@ sub _parse_sheet {
                 $twig->purge;
             },
 
-            'sheetPr/tabColor' => sub {
+            's:sheetPr/s:tabColor' => sub {
                 my ( $twig, $tab_color ) = @_;
 
                 $sheet->{TabColor} = $self->_color($sheet->{_Book}{Color}, $tab_color);
@@ -310,20 +319,10 @@ sub _parse_sheet {
                 $twig->purge;
             },
 
-        }
-    );
-
-    $sheet_xml->parse( $sheet_file );
-
-    # 2nd pass: cell/row building is dependent on having parsed the merge definitions
-    # beforehand.
-
-    $sheet_xml = XML::Twig->new(
-        twig_roots => {
-            'sheetData/row' => sub {
+            's:sheetData/s:row' => sub {
                 my ( $twig, $row_elt ) = @_;
 
-                for my $cell ( $row_elt->children('c') ){
+                for my $cell ( $row_elt->children('s:c') ){
                     my ($row, $col) = $self->_cell_to_row_col($cell->att('r'));
                     $sheet->{MaxRow} = $row
                         if $sheet->{MaxRow} < $row;
@@ -332,21 +331,23 @@ sub _parse_sheet {
                     my $type = $cell->att('t') || 'n';
                     my $val_xml;
                     if ($type ne 'inlineStr') {
-                        $val_xml = $cell->first_child('v');
+                        $val_xml = $cell->first_child('s:v');
                     }
-                    elsif (defined $cell->first_child('is')) {
-                        $val_xml = ($cell->find_nodes('.//t'))[0];
+                    elsif (defined $cell->first_child('s:is')) {
+                        $val_xml = ($cell->find_nodes('.//s:t'))[0];
                     }
                     my $val = $val_xml ? $val_xml->text : undef;
 
                     my $long_type;
+                    my $Rich;
                     if (!defined($val)) {
                         $long_type = 'Text';
                         $val = '';
                     }
                     elsif ($type eq 's') {
                         $long_type = 'Text';
-                        $val = $sheet->{_Book}{PkgStr}[$val];
+                        $Rich = $sheet->{_Book}{Rich}->{$val};
+                        $val  = $sheet->{_Book}{PkgStr}[$val];
                     }
                     elsif ($type eq 'n') {
                         $long_type = 'Numeric';
@@ -371,9 +372,7 @@ sub _parse_sheet {
 
                     my $format_idx = $cell->att('s') || 0;
                     my $format = $sheet->{_Book}{Format}[$format_idx];
-                    $format->{Merged} = !!grep {
-                        $row == $_->[0] && $col == $_->[1]
-                    } @merged_cells;
+                    die "unknown format $format_idx" unless $format;
 
                     # see the list of built-in formats below in _parse_styles
                     # XXX probably should figure this out from the actual format string,
@@ -382,30 +381,36 @@ sub _parse_sheet {
                         $long_type = 'Date';
                     }
 
+                    my $formula = $cell->first_child('s:f');
                     my $cell = Spreadsheet::ParseExcel::Cell->new(
                         Val      => $val,
                         Type     => $long_type,
-                        Merged   => $format->{Merged},
+                        Merged   => undef, # fix up later
                         Format   => $format,
                         FormatNo => $format_idx,
-                        ($cell->first_child('f')
-                            ? (Formula => $cell->first_child('f')->text)
+                        ($formula
+                            ? (Formula => $formula->text)
                             : ()),
+                        Rich     => $Rich,
                     );
                     $cell->{_Value} = $sheet->{_Book}{FmtClass}->ValFmt(
                         $cell, $sheet->{_Book}
                     );
+                    $cells{"$row;$col"} = $cell;
                     $sheet->{Cells}[$row][$col] = $cell;
                 }
 
                 $twig->purge;
             },
-
         }
     );
 
     $sheet_xml->parse( $sheet_file );
 
+    for my $key (keys %merged_cells) {
+        $cells{$key}{Merged} = 1 if $cells{$key};
+    }
+
     if ( ! $sheet->{Cells} ){
         $sheet->{MaxRow} = $sheet->{MaxCol} = -1;
     }
@@ -424,29 +429,125 @@ sub _parse_sheet {
 
 }
 
+sub _get_text_and_rich_font_by_cell {
+    my $self = shift;
+    my ($si, $theme_colors) = @_;
+
+    # XXX
+    my %default_font_opts = (
+        Height         => 12,
+        Color          => '#000000',
+        Name           => '',
+        Bold           => 0,
+        Italic         => 0,
+        Underline      => 0,
+        UnderlineStyle => 0,
+        Strikeout      => 0,
+        Super          => 0,
+    );
+
+    my $string_text = '';
+    my @rich_font_by_cell;
+    my @nodes_r = $si->find_nodes('.//s:r');
+    if (@nodes_r > 0) {
+        for my $chunk (map { $_->children } @nodes_r) {
+            my $string_length = length($string_text);
+            if ($chunk->name eq 's:t') {
+                if (!@rich_font_by_cell) {
+                    push @rich_font_by_cell, [
+                        $string_length,
+                        Spreadsheet::ParseExcel::Font->new(%default_font_opts)
+                    ];
+                }
+                $string_text .= $chunk->text;
+            }
+            elsif ($chunk->name eq 's:rPr') {
+                my %format_text = %default_font_opts;
+                for my $node_format ($chunk->children) {
+                    if ($node_format->name eq 's:sz') {
+                        $format_text{Height} = $node_format->att('val');
+                    }
+                    elsif ($node_format->name eq 's:color') {
+                        $format_text{Color} = $self->_color(
+                            $theme_colors,
+                            $node_format
+                        );
+                    }
+                    elsif ($node_format->name eq 's:rFont') {
+                        $format_text{Name} = $node_format->att('val');
+                    }
+                    elsif ($node_format->name eq 's:b') {
+                        $format_text{Bold} = 1;
+                    }
+                    elsif ($node_format->name eq 's:i') {
+                        $format_text{Italic} = 1;
+                    }
+                    elsif ($node_format->name eq 's:u') {
+                        $format_text{Underline} = 1;
+                        if (defined $node_format->att('val')) {
+                            $format_text{UnderlineStyle} = 2;
+                        } else {
+                            $format_text{UnderlineStyle} = 1;
+                        }
+                    }
+                    elsif ($node_format->name eq 's:strike') {
+                        $format_text{Strikeout} = 1;
+                    }
+                    elsif ($node_format->name eq 's:vertAlign') {
+                        if ($node_format->att('val') eq 'superscript') {
+                            $format_text{Super} = 1;
+                        }
+                        elsif ($node_format->att('val') eq 'subscript') {
+                            $format_text{Super} = 2;
+                        }
+                    }
+                }
+                push @rich_font_by_cell, [
+                    $string_length,
+                    Spreadsheet::ParseExcel::Font->new(%format_text)
+                ];
+            }
+        }
+    }
+    else {
+        $string_text = join '', map { $_->text } $si->find_nodes('.//s:t');
+    }
+
+    return (
+        String => $string_text,
+        Rich => \@rich_font_by_cell,
+    );
+}
+
 sub _parse_shared_strings {
     my $self = shift;
-    my ($strings) = @_;
+    my ($strings, $theme_colors) = @_;
 
     my $PkgStr = [];
 
+    my %richfonts;
     if ($strings) {
-        my $xml = XML::Twig->new(
+        my $xml = $self->_new_twig(
             twig_handlers => {
-                'si' => sub {
+                's:si' => sub {
                     my ( $twig, $si ) = @_;
 
-                    # XXX this discards information about formatting within cells
-                    # not sure how to represent that
-                    push @$PkgStr,
-                      join( '', map { $_->text } $si->find_nodes('.//t') );
+                    my %text_rich = $self->_get_text_and_rich_font_by_cell(
+                        $si,
+                        $theme_colors
+                    );
+                    $richfonts{scalar @$PkgStr} = $text_rich{Rich};
+                    push @$PkgStr, $text_rich{String};
                     $twig->purge;
                 },
             }
         );
         $xml->parse( $strings );
     }
-    return $PkgStr;
+    return (
+        Rich   => \%richfonts,
+        PkgStr => $PkgStr,
+    );
 }
 
 sub _parse_themes {
@@ -456,8 +557,8 @@ sub _parse_themes {
     return {} unless $themes;
 
     my @color = map {
-        $_->name eq 'a:sysClr' ? $_->att('lastClr') : $_->att('val')
-    } $themes->find_nodes('//a:clrScheme/*/*');
+        $_->name eq 'drawmain:sysClr' ? $_->att('lastClr') : $_->att('val')
+    } $themes->find_nodes('//drawmain:clrScheme/*/*');
 
     # this shouldn't be necessary, but the documentation is wrong here
     # see http://stackoverflow.com/questions/2760976/theme-confusion-in-spreadsheetml
@@ -473,6 +574,85 @@ sub _parse_styles {
     my $self = shift;
     my ($workbook, $styles) = @_;
 
+    # these defaults are from
+    # http://social.msdn.microsoft.com/Forums/en-US/oxmlsdk/thread/e27aaf16-b900-4654-8210-83c5774a179c
+    my %default_format_str = (
+        0  => 'GENERAL',
+        1  => '0',
+        2  => '0.00',
+        3  => '#,##0',
+        4  => '#,##0.00',
+        5  => '$#,##0_);($#,##0)',
+        6  => '$#,##0_);[Red]($#,##0)',
+        7  => '$#,##0.00_);($#,##0.00)',
+        8  => '$#,##0.00_);[Red]($#,##0.00)',
+        9  => '0%',
+        10 => '0.00%',
+        11 => '0.00E+00',
+        12 => '# ?/?',
+        13 => '# ??/??',
+        14 => 'm/d/yyyy',
+        15 => 'd-mmm-yy',
+        16 => 'd-mmm',
+        17 => 'mmm-yy',
+        18 => 'h:mm AM/PM',
+        19 => 'h:mm:ss AM/PM',
+        20 => 'h:mm',
+        21 => 'h:mm:ss',
+        22 => 'm/d/yyyy h:mm',
+        37 => '#,##0_);(#,##0)',
+        38 => '#,##0_);[Red](#,##0)',
+        39 => '#,##0.00_);(#,##0.00)',
+        40 => '#,##0.00_);[Red](#,##0.00)',
+        45 => 'mm:ss',
+        46 => '[h]:mm:ss',
+        47 => 'mm:ss.0',
+        48 => '##0.0E+0',
+        49 => '@',
+    );
+
+    my %default_format_opts = (
+        IgnoreFont         => 1,
+        IgnoreFill         => 1,
+        IgnoreBorder       => 1,
+        IgnoreAlignment    => 1,
+        IgnoreNumberFormat => 1,
+        IgnoreProtection   => 1,
+        FontNo             => 0,
+        FmtIdx             => 0,
+        Lock               => 1,
+        Hidden             => 0,
+        AlignH             => 0,
+        Wrap               => 0,
+        AlignV             => 2,
+        Rotate             => 0,
+        Indent             => 0,
+        Shrink             => 0,
+        BdrStyle           => [0, 0, 0, 0],
+        BdrColor           => [undef, undef, undef, undef],
+        BdrDiag            => [0, 0, undef],
+        Fill               => [0, undef, undef],
+    );
+
+    if (!$styles) {
+        # XXX i guess?
+        my $font = Spreadsheet::ParseExcel::Font->new(
+            Height         => 12,
+            Color          => '#000000',
+            Name           => '',
+        );
+        my $format = Spreadsheet::ParseExcel::Format->new(
+            %default_format_opts,
+            Font => $font,
+        );
+
+        return {
+            FormatStr => \%default_format_str,
+            Font      => [ $font ],
+            Format    => [ $format ],
+        };
+    }
+
     my %halign = (
         center           => 2,
         centerContinuous => 6,
@@ -532,12 +712,13 @@ sub _parse_styles {
     );
 
     my @fills = map {
+        my $pattern_type = $_->att('patternType');
         [
-            $fill{$_->att('patternType')},
-            $self->_color($workbook->{Color}, $_->first_child('fgColor'), 1),
-            $self->_color($workbook->{Color}, $_->first_child('bgColor'), 1),
+            ($pattern_type ? $fill{$pattern_type} : 0),
+            $self->_color($workbook->{Color}, $_->first_child('s:fgColor'), 1),
+            $self->_color($workbook->{Color}, $_->first_child('s:bgColor'), 1),
         ]
-    } $styles->find_nodes('//fills/fill/patternFill');
+    } $styles->find_nodes('//s:fills/s:fill/s:patternFill');
 
     my @borders = map {
         my $border = $_;
@@ -545,12 +726,12 @@ sub _parse_styles {
             $self->_xml_boolean($border->att($_))
         } qw(diagonalDown diagonalUp);
         my %borderstyles = map {
-            my $e = $border->first_child($_);
+            my $e = $border->first_child("s:$_");
             $_ => ($e ? $e->att('style') || 'none' : 'none')
         } qw(left right top bottom diagonal);
         my %bordercolors = map {
-            my $e = $border->first_child($_);
-            $_ => ($e ? $e->first_child('color') : undef)
+            my $e = $border->first_child("s:$_");
+            $_ => ($e ? $e->first_child('s:color') : undef)
         } qw(left right top bottom diagonal);
         # XXX specs say "begin" and "end" rather than "left" and "right",
         # but... that's not what seems to be in the file itself (sigh)
@@ -574,55 +755,22 @@ sub _parse_styles {
                 $self->_color($workbook->{Color}, $bordercolors{diagonal}),
             ],
         }
-    } $styles->find_nodes('//borders/border');
+    } $styles->find_nodes('//s:borders/s:border');
 
-    # these defaults are from
-    # http://social.msdn.microsoft.com/Forums/en-US/oxmlsdk/thread/e27aaf16-b900-4654-8210-83c5774a179c
     my %format_str = (
-        0  => 'GENERAL',
-        1  => '0',
-        2  => '0.00',
-        3  => '#,##0',
-        4  => '#,##0.00',
-        5  => '$#,##0_);($#,##0)',
-        6  => '$#,##0_);[Red]($#,##0)',
-        7  => '$#,##0.00_);($#,##0.00)',
-        8  => '$#,##0.00_);[Red]($#,##0.00)',
-        9  => '0%',
-        10 => '0.00%',
-        11 => '0.00E+00',
-        12 => '# ?/?',
-        13 => '# ??/??',
-        14 => 'm/d/yyyy',
-        15 => 'd-mmm-yy',
-        16 => 'd-mmm',
-        17 => 'mmm-yy',
-        18 => 'h:mm AM/PM',
-        19 => 'h:mm:ss AM/PM',
-        20 => 'h:mm',
-        21 => 'h:mm:ss',
-        22 => 'm/d/yyyy h:mm',
-        37 => '#,##0_);(#,##0)',
-        38 => '#,##0_);[Red](#,##0)',
-        39 => '#,##0.00_);(#,##0.00)',
-        40 => '#,##0.00_);[Red](#,##0.00)',
-        45 => 'mm:ss',
-        46 => '[h]:mm:ss',
-        47 => 'mm:ss.0',
-        48 => '##0.0E+0',
-        49 => '@',
+        %default_format_str,
         (map {
             $_->att('numFmtId') => $_->att('formatCode')
-        } $styles->find_nodes('//numFmts/numFmt')),
+        } $styles->find_nodes('//s:numFmts/s:numFmt')),
     );
 
     my @font = map {
-        my $vert = $_->first_child('vertAlign');
-        my $under = $_->first_child('u');
-        my $heightelem = $_->first_child('sz');
+        my $vert = $_->first_child('s:vertAlign');
+        my $under = $_->first_child('s:u');
+        my $heightelem = $_->first_child('s:sz');
         # XXX i guess 12 is okay?
         my $height = 0+($heightelem ? $heightelem->att('val') : 12);
-        my $nameelem = $_->first_child('name');
+        my $nameelem = $_->first_child('s:name');
         my $name = $nameelem ? $nameelem->att('val') : '';
         Spreadsheet::ParseExcel::Font->new(
             Height         => $height,
@@ -631,10 +779,10 @@ sub _parse_styles {
             # intact rather than just going straight to #xxxxxx
             # XXX also not sure what it means for the color tag to be missing,
             # just assuming black for now
-            Color          => ($_->first_child('color')
+            Color          => ($_->first_child('s:color')
                 ? $self->_color(
                     $workbook->{Color},
-                    $_->first_child('color')
+                    $_->first_child('s:color')
                 )
                 : '#000000'
             ),
@@ -659,61 +807,56 @@ sub _parse_styles {
             ),
             Name           => $name,
 
-            Bold      => $_->has_child('b') ? 1 : 0,
-            Italic    => $_->has_child('i') ? 1 : 0,
-            Underline => $_->has_child('u') ? 1 : 0,
-            Strikeout => $_->has_child('strike') ? 1 : 0,
+            Bold      => $_->has_child('s:b') ? 1 : 0,
+            Italic    => $_->has_child('s:i') ? 1 : 0,
+            Underline => $_->has_child('s:u') ? 1 : 0,
+            Strikeout => $_->has_child('s:strike') ? 1 : 0,
         )
-    } $styles->find_nodes('//fonts/font');
+    } $styles->find_nodes('//s:fonts/s:font');
 
     my @format = map {
-        my $alignment  = $_->first_child('alignment');
-        my $protection = $_->first_child('protection');
-        Spreadsheet::ParseExcel::Format->new(
-            IgnoreFont         => !$self->_xml_boolean($_->att('applyFont')),
-            IgnoreFill         => !$self->_xml_boolean($_->att('applyFill')),
-            IgnoreBorder       => !$self->_xml_boolean($_->att('applyBorder')),
-            IgnoreAlignment    => !$self->_xml_boolean($_->att('applyAlignment')),
-            IgnoreNumberFormat => !$self->_xml_boolean($_->att('applyNumberFormat')),
-            IgnoreProtection   => !$self->_xml_boolean($_->att('applyProtection')),
+        my $xml_fmt = $_;
+        my $alignment  = $xml_fmt->first_child('s:alignment');
+        my $protection = $xml_fmt->first_child('s:protection');
+        my %ignore = map {
+            ("Ignore$_" => !$self->_xml_boolean($xml_fmt->att("apply$_")))
+        } qw(Font Fill Border Alignment NumberFormat Protection);
+        my %opts = (
+            %default_format_opts,
+            %ignore,
+        );
 
-            FontNo => 0+$_->att('fontId'),
-            Font   => $font[$_->att('fontId')],
-            FmtIdx => 0+$_->att('numFmtId'),
+        $opts{FmtIdx}   = 0+($xml_fmt->att('numFmtId')||0);
+        $opts{FontNo}   = 0+($xml_fmt->att('fontId')||0);
+        $opts{Font}     = $font[$opts{FontNo}];
+        $opts{Fill}     = $fills[$xml_fmt->att('fillId')||0];
+        $opts{BdrStyle} = $borders[$xml_fmt->att('borderId')||0]{styles};
+        $opts{BdrColor} = $borders[$xml_fmt->att('borderId')||0]{colors};
+        $opts{BdrDiag}  = $borders[$xml_fmt->att('borderId')||0]{diagonal};
 
-            Lock => $protection && defined $protection->att('locked')
-                ? $self->_xml_boolean($protection->att('locked'))
-                : 1,
-            Hidden => $protection
-                ? $self->_xml_boolean($protection->att('hidden'))
-                : 0,
-            # Style    => $iStyle,
-            # Key123   => $i123,
-            AlignH => $alignment
-                ? $halign{$alignment->att('horizontal') || 'general'}
-                : 0,
-            Wrap => $alignment
-                ? $self->_xml_boolean($alignment->att('wrapText'))
-                : 0,
-            AlignV => $alignment
-                ? $valign{$alignment->att('vertical') || 'bottom'}
-                : 2,
+        if ($alignment) {
+            $opts{AlignH} = $halign{$alignment->att('horizontal') || 'general'};
+            $opts{Wrap}   = $self->_xml_boolean($alignment->att('wrapText'));
+            $opts{AlignV} = $valign{$alignment->att('vertical') || 'bottom'};
+            $opts{Rotate} = $alignment->att('textRotation');
+            $opts{Indent} = $alignment->att('indent');
+            $opts{Shrink} = $self->_xml_boolean($alignment->att('shrinkToFit'));
             # JustLast => $iJustL,
-            Rotate => $alignment ? $alignment->att('textRotation') : 0,
+        }
 
-            Indent => $alignment ? $alignment->att('indent') : 0,
-            Shrink => $alignment
-                ? $self->_xml_boolean($alignment->att('shrinkToFit'))
-                : 0,
-            # Merge   => $iMerge,
-            # ReadDir => $iReadDir,
+        if ($protection) {
+            $opts{Lock} = defined $protection->att('locked')
+                ? $self->_xml_boolean($protection->att('locked'))
+                : 1;
+            $opts{Hidden} = $self->_xml_boolean($protection->att('hidden'));
+        }
 
-            BdrStyle => $borders[$_->att('borderId')]{styles},
-            BdrColor => $borders[$_->att('borderId')]{colors},
-            BdrDiag  => $borders[$_->att('borderId')]{diagonal},
-            Fill     => $fills[$_->att('fillId')],
-        )
-    } $styles->find_nodes('//cellXfs/xf');
+        # Style    => $iStyle,
+        # Key123   => $i123,
+        # Merge   => $iMerge,
+        # ReadDir => $iReadDir,
+        Spreadsheet::ParseExcel::Format->new(%opts)
+    } $styles->find_nodes('//s:cellXfs/s:xf');
 
     return {
         FormatStr => \%format_str,
@@ -731,10 +874,10 @@ sub _extract_files {
 
     my $rels = $self->_parse_xml(
         $zip,
-        $self->_rels_for('')
+        $self->_rels_for(''),
     );
     my $wb_name = ($rels->find_nodes(
-        qq<//Relationship[\@Type="$type_base/officeDocument"]>
+        qq<//packagerels:Relationship[\@Type="$type_base/officeDocument"]>
     ))[0]->att('Target');
     $wb_name =~ s{^/}{};
     my $wb_xml = $self->_parse_xml($zip, $wb_name);
@@ -742,7 +885,7 @@ sub _extract_files {
     my $path_base = $self->_base_path_for($wb_name);
     my $wb_rels = $self->_parse_xml(
         $zip,
-        $self->_rels_for($wb_name)
+        $self->_rels_for($wb_name),
     );
 
     my $get_path = sub {
@@ -754,31 +897,31 @@ sub _extract_files {
     };
 
     my ($strings_xml) = map {
-        $zip->memberNamed($get_path->($_->att('Target')))->contents
-    } $wb_rels->find_nodes(qq<//Relationship[\@Type="$type_base/sharedStrings"]>);
+        $self->_zip_file_member($zip, $get_path->($_->att('Target')))
+    } $wb_rels->find_nodes(qq<//packagerels:Relationship[\@Type="$type_base/sharedStrings"]>);
 
-    my $styles_xml = $self->_parse_xml(
-        $zip,
-        $get_path->(($wb_rels->find_nodes(
-            qq<//Relationship[\@Type="$type_base/styles"]>
-        ))[0]->att('Target'))
-    );
+    my ($styles_xml) = map {
+        $self->_parse_xml(
+            $zip,
+            $get_path->($_->att('Target'))
+        )
+    } $wb_rels->find_nodes(qq<//packagerels:Relationship[\@Type="$type_base/styles"]>);
 
     my %worksheet_xml = map {
-        if ( my $sheetfile = $zip->memberNamed($get_path->($_->att('Target')))->contents ) {
-            ( $_->att('Id') => $sheetfile );
-        }
-    } $wb_rels->find_nodes(qq<//Relationship[\@Type="$type_base/worksheet"]>);
+        ($_->att('Id') => $self->_zip_file_member($zip, $get_path->($_->att('Target'))))
+    } $wb_rels->find_nodes(qq<//packagerels:Relationship[\@Type="$type_base/worksheet"]>);
 
     my %themes_xml = map {
         $_->att('Id') => $self->_parse_xml($zip, $get_path->($_->att('Target')))
-    } $wb_rels->find_nodes(qq<//Relationship[\@Type="$type_base/theme"]>);
+    } $wb_rels->find_nodes(qq<//packagerels:Relationship[\@Type="$type_base/theme"]>);
 
     return {
         workbook => $wb_xml,
-        styles   => $styles_xml,
         sheets   => \%worksheet_xml,
         themes   => \%themes_xml,
+        ($styles_xml
+            ? (styles  => $styles_xml)
+            : ()),
         ($strings_xml
             ? (strings => $strings_xml)
             : ()),
@@ -787,17 +930,24 @@ sub _extract_files {
 
 sub _parse_xml {
     my $self = shift;
-    my ($zip, $subfile) = @_;
+    my ($zip, $subfile, $map_xmlns) = @_;
 
-    my $member = $zip->memberNamed($subfile);
-    die "no subfile named $subfile" unless $member;
-
-    my $xml = XML::Twig->new;
-    $xml->parse(scalar $member->contents);
+    my $xml = $self->_new_twig;
+    $xml->parse($self->_zip_file_member($zip, $subfile));
 
     return $xml;
 }
 
+sub _zip_file_member {
+    my $self = shift;
+    my ($zip, $name) = @_;
+
+    my @members = $zip->membersMatching(qr/^$name$/i);
+    die "no subfile named $name" unless @members;
+
+    return scalar $members[0]->contents;
+}
+
 sub _rels_for {
     my $self = shift;
     my ($file) = @_;
@@ -884,7 +1034,7 @@ sub _color {
                 $color = "#$theme";
             }
             else {
-                return;
+                return undef;
             }
         }
 
@@ -912,6 +1062,22 @@ sub _apply_tint {
     return scalar hls2rgb($h, $l, $s);
 }
 
+sub _new_twig {
+    my $self = shift;
+    my %opts = @_;
+
+    return XML::Twig->new(
+        map_xmlns => {
+            'http://schemas.openxmlformats.org/spreadsheetml/2006/main' => 's',
+            'http://schemas.openxmlformats.org/package/2006/relationships' => 'packagerels',
+            'http://schemas.openxmlformats.org/officeDocument/2006/relationships' => 'rels',
+            'http://schemas.openxmlformats.org/drawingml/2006/main' => 'drawmain',
+        },
+        keep_original_prefix => 1,
+        %opts,
+    );
+}
+
 
 1;
 
@@ -927,7 +1093,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.20
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -1084,7 +1250,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
