@@ -1,6 +1,6 @@
 package Spreadsheet::ParseXLSX::Decryptor;
 our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::Decryptor::VERSION = '0.20';
+$Spreadsheet::ParseXLSX::Decryptor::VERSION = '0.23';
 use strict;
 use warnings;
 
@@ -27,9 +27,11 @@ sub open {
         ['EncryptionInfo', 'EncryptedPackage']
     );
 
+    return unless $infoFH;
+
     my $buffer;
     $infoFH->read($buffer, 8);
-    my ($majorVers, $minorVers) = unpack('SS', $buffer);
+    my ($majorVers, $minorVers) = unpack('s<s<', $buffer);
 
     my $xlsx;
     if ($majorVers == 4 && $minorVers == 4) {
@@ -72,13 +74,13 @@ sub _standardDecryption {
     my $buffer;
     my $n = $infoFH->read($buffer, 24);
 
-    my ($encryptionHeaderSize, undef, undef, $algID, $algIDHash, $keyBits) = unpack('LLLLLL', $buffer);
+    my ($encryptionHeaderSize, undef, undef, $algID, $algIDHash, $keyBits) = unpack('L<*', $buffer);
 
     $infoFH->seek($encryptionHeaderSize - 0x14, IO::File::SEEK_CUR);
 
     $infoFH->read($buffer, 4);
 
-    my $saltSize = unpack('L', $buffer);
+    my $saltSize = unpack('L<', $buffer);
 
     my ($salt, $encryptedVerifier, $verifierHashSize, $encryptedVerifierHash);
 
@@ -86,7 +88,7 @@ sub _standardDecryption {
     $infoFH->read($encryptedVerifier, 16);
 
     $infoFH->read($buffer, 4);
-    $verifierHashSize = unpack('L', $buffer);
+    $verifierHashSize = unpack('L<', $buffer);
 
     $infoFH->read($encryptedVerifierHash, 32);
     $infoFH->close();
@@ -122,7 +124,7 @@ sub _standardDecryption {
 
     my $inbuf;
     $packageFH->read($inbuf, 8);
-    my $fileSize = unpack('L', $inbuf);
+    my $fileSize = unpack('L<', $inbuf);
 
     $decryptor->decryptFile($packageFH, $fh, 1024, $fileSize);
 
@@ -176,7 +178,7 @@ sub _agileDecryption {
 
     my $inbuf;
     $packageFH->read($inbuf, 8);
-    my $fileSize = unpack('L', $inbuf);
+    my $fileSize = unpack('L<', $inbuf);
 
     $fileDecryptor->decryptFile($packageFH, $fh, 4096, $key, $fileSize);
 
@@ -220,7 +222,7 @@ Spreadsheet::ParseXLSX::Decryptor
 
 =head1 VERSION
 
-version 0.20
+version 0.23
 
 =for Pod::Coverage   new
   open
@@ -231,7 +233,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
