@@ -1,6 +1,6 @@
 package Spreadsheet::ParseXLSX::Decryptor::Agile;
 our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::Decryptor::Agile::VERSION = '0.20';
+$Spreadsheet::ParseXLSX::Decryptor::Agile::VERSION = '0.23';
 use strict;
 use warnings;
 
@@ -25,7 +25,7 @@ sub _generateDecryptionKey {
     unless ($self->{pregeneratedKey}) {
         $hash = $self->{hashProc}->($self->{salt} . Encode::encode('UTF-16LE', $self->{password}));
         for (my $i = 0; $i < $self->{spinCount}; $i++) {
-            $hash = $self->{hashProc}->(pack('L', $i) . $hash);
+            $hash = $self->{hashProc}->(pack('L<', $i) . $hash);
         }
         $self->{pregeneratedKey} = $hash;
     }
@@ -70,7 +70,7 @@ sub decryptFile {
     my $i = 0;
 
     while (($fileSize > 0) && (my $inlen = $inFile->read($inbuf, $bufferLength))) {
-        my $blockId = pack('L', $i);
+        my $blockId = pack('L<', $i);
 
         my $iv = $self->_generateInitializationVector($blockId, $self->{blockSize});
 
@@ -114,7 +114,7 @@ Spreadsheet::ParseXLSX::Decryptor::Agile
 
 =head1 VERSION
 
-version 0.20
+version 0.23
 
 =for Pod::Coverage   decrypt
   decryptFile
@@ -126,7 +126,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
