@@ -1,6 +1,6 @@
 package Spreadsheet::ParseXLSX::Decryptor::Standard;
 our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::Decryptor::Standard::VERSION = '0.20';
+$Spreadsheet::ParseXLSX::Decryptor::Standard::VERSION = '0.23';
 use strict;
 use warnings;
 
@@ -49,7 +49,7 @@ sub _generateDecryptionKey {
     unless ($self->{pregeneratedKey}) {
         $hash = $self->{hashProc}->($self->{salt} . Encode::encode('UTF-16LE', $self->{password}));
         for (my $i = 0; $i < $self->{spinCount}; $i++) {
-            $hash = $self->{hashProc}->(pack('L', $i) . $hash);
+            $hash = $self->{hashProc}->(pack('L<', $i) . $hash);
         }
         $self->{pregeneratedKey} = $hash;
     }
@@ -94,7 +94,7 @@ Spreadsheet::ParseXLSX::Decryptor::Standard
 
 =head1 VERSION
 
-version 0.20
+version 0.23
 
 =for Pod::Coverage   decrypt
   decryptFile
@@ -106,7 +106,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Jesse Luehrs.
+This software is Copyright (c) 2016 by Jesse Luehrs.
 
 This is free software, licensed under:
 
